@@ -237,7 +237,7 @@ SMALL = 2.0**(-30)
 SMALLEST_COUNTEREXAMPLE_FASTPRIME = 2047
 T = (type(mpz(1)), type(1), type(1))
 DUMMY = 'dummy' # Dummy value throughout the program
-VERSION = '2.0.3 (Python 3)'
+VERSION = '2.0.5 (Python 3)'
 _12_LOG_2_OVER_49 = 12 * math.log(2) / 49
 RECORD = 1162795072109807846655696105569042240239
 
@@ -911,7 +911,7 @@ def mainloop(n, u, p1):
    small_jump = max(120, small_jump)
    big_jump = 1 + (int(sqrt((5 << w) // 21)) << 1)
    total_jump = small_jump * big_jump
-   big_multiple = max(total_jump << 1, ((int(next_prime(prime)) - (total_jump >> 1)) / total_jump) * total_jump)
+   big_multiple = max(total_jump << 1, ((int(next_prime(prime)) - (total_jump >> 1)) // total_jump) * total_jump)
    big_jump_2 = big_jump >> 1
    small_jump_2 = small_jump >> 1
    product = ONE
@@ -1258,13 +1258,16 @@ Notes:
    if type(n) not in T:
       raise ValueError('Number given must be integer or long.')
 
+   if n == 0:
+      raise ValueError('Number given must be greater than 0.')
+
    if not 0 < pr <= 1:
       yield 'Error: pr must be between 0 and 1'
       return
 
    while not n & 1:
       n >>= 1
-      yield 2
+      yield mpz(2)
 
    n = mpz(n)
    k = inv_const(n)
